@@ -7,7 +7,7 @@ use warnings;
 use Exporter;
 use Carp;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw(
@@ -249,6 +249,7 @@ sub stream_new {
   return Video::Xine::Stream->new($self->{'xine'}, $audio_port, $video_port);
 }
 
+
 package Video::Xine::Stream;
 
 sub new {
@@ -349,6 +350,13 @@ sub get_param {
   return xine_get_param($self->{'stream'}, $param);
 }
 
+sub osd_new {
+    my $self = shift;
+    my (%in) = @_;
+
+    return Video::Xine::OSD->new($self, %in);
+}
+
 sub DESTROY {
   my $self = shift;
   xine_dispose($self->{'stream'});
@@ -463,6 +471,71 @@ sub get_event {
   bless $event, 'Video::Xine::Event';
 }
 
+package Video::Xine::OSD;
+
+use Carp;
+
+sub new {
+    my ($type) = shift;
+    my (%in) = @_;
+
+    defined $in{'stream'} or croak "Argument 'stream' required!";
+
+    my $self = {};
+    $self->{'stream'} = $in{'stream'};
+    $self->{'x'} = $in{'x'};
+    $self->{'y'} = $in{'y'};
+    $self->{'width'} = $in{'width'};
+    $self->{'height'} = $in{'height'};
+
+    $self->{'osd'} = xine_osd_new($self->{'stream'}{'stream'},
+				  $self->{'x'},
+				  $self->{'y'},
+				  $self->{'width'},
+				  $self->{'height'}
+				 );
+
+    bless $self, $type;
+    return $self;
+}
+
+sub clear {
+    my $self = shift;
+
+    xine_osd_clear($self->{'osd'});
+}
+
+sub draw_text {
+    my $self = shift;
+    my (%in) = @_;
+
+    xine_osd_draw_text($self->{'osd'}, $in{'x'}, $in{'y'}, $in{'text'}, $in{'color_base'})
+}
+
+sub set_font {
+    my $self = shift;
+    my ($fontname, $fontsize) = @_;
+
+    xine_osd_set_font($self->{'osd'}, $fontname, $fontsize)
+}
+
+sub show {
+    my $self = shift;
+
+    xine_osd_show($self->{'osd'}, 0);
+}
+
+sub hide {
+    my $self = shift;
+
+    xine_osd_hide($self->{'osd'}, 0)
+}
+
+sub DESTROY {
+    my $self = shift;
+    xine_osd_free($self->{'osd'});
+}
+
 1;
 __END__
 
@@ -788,6 +861,49 @@ Example:
   my $driver = Video::Xine::Driver::Video->new($xine,"Xv",XINE_VISUAL_TYPE_X11, $x11_visual)
     or die "Couldn't load video driver";
 
+=head2 OSD METHODS
+
+These methods are used for the Xine on-screen display.
+
+=head3 osd_new()
+
+  my $osd = $stream->osd_new($x, $y, $width, $height);
+
+Creates a new OSD.
+
+=head3 clear()
+
+ $osd->clear()
+
+Clears out the on-screen display.
+
+=head3 draw_text()
+
+ $osd->draw_text(x => 0, y => 0, text => 'hello world', color_base => 1)
+
+Draw text on the on-screen display. Set the font with C<set_font()>
+before calling this method, or no text will be drawn.
+
+=head3 set_font()
+
+ $osd->set_font($font_name, $font_size);
+
+Sets the font and font size. C<$font_name> can be either a straight
+name or a path to a TrueType font file. C<$font_size> is the point
+size of the font. The Xine header seems to want you to make this a
+multiple of 11; not sure why.
+
+=head3 show()
+
+ $osd->show();
+
+Renders the OSD onto the screen.
+
+=head3 hide()
+
+ $osd->hide();
+
+Hides the OSD from the screen.
 
 =head2 UTILITY SUBROUTINES
 
